/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.streams.plugins.test;

import org.apache.streams.plugins.StreamsScalaSourceGenerator;

import org.apache.commons.io.FileUtils;
import org.junit.Assert;
import org.junit.Test;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.io.File;
import java.util.Collection;

import static org.apache.streams.plugins.test.StreamsScalaSourceGeneratorTest.scalaFilter;

/**
 * Test whether StreamsScalaSourceGeneratorCLI generates sources.
 */
public class StreamsScalaSourceGeneratorCLITest {

  private static final Logger LOGGER = LoggerFactory.getLogger(StreamsScalaSourceGeneratorCLITest.class);

  @Test
  public void testStreamsScalaSourceGeneratorCLI() throws Exception {

    String sourcePackages = "org.apache.streams.pojo.json";
    String targetPackage = "org.apache.streams.scala";
    String targetDirectory = "./target/generated-sources/scala-cli";

    StreamsScalaSourceGenerator.main(new String[]{sourcePackages, targetDirectory, targetPackage});

    File testOutput = new File(targetDirectory);

    Assert.assertNotNull(testOutput);
    Assert.assertTrue(testOutput.exists() );
    Assert.assertTrue(testOutput.isDirectory());

    Collection<File> outputCollection = FileUtils.listFiles(testOutput, scalaFilter, true);
    assert ( outputCollection.size() >= 4 );
  }
}
