/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.streams.util;

import com.google.common.hash.Hashing;
import org.apache.commons.lang3.StringUtils;

import java.nio.charset.Charset;
import java.util.Arrays;
import java.util.Objects;

/**
 * GuidUtils contains methods for generating guids from identifiers.
 */
public class GuidUtils {

  private static final Charset UTF8_CHARSET = Charset.forName("UTF-8");

  /**
   * generateGuid from list of parts.
   * @param parts list of parts
   * @return guid
   */
  public static String generateGuid(String... parts) {

    StringBuilder seed = new StringBuilder();

    for ( String part : parts ) {
      Objects.requireNonNull(part);
      if(StringUtils.isNotBlank(part)) {
        seed.append(part);
      }
    }

    return Arrays.toString(Hashing.goodFastHash(24).hashString(seed, UTF8_CHARSET).asBytes());

  }
}
